<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/ecrire_?lang_cible=pt_br
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'activer_plugin' => 'Ativar o plugin',
	'affichage' => 'Exibição',
	'aide_non_disponible' => 'Esta parte da ajuda online ainda não está disponível neste idioma.',
	'annuler_recherche' => 'Cancelar a busca',
	'auteur' => 'Autor:',
	'avis_acces_interdit' => 'Acesso negado.',
	'avis_acces_interdit_prive' => 'Você não está autorizado a acessar a página <b>@exec@</b>.',
	'avis_article_modifie' => 'Atenção, @nom_auteur_modif@ editou esta matéria há @date_diff@ minutos',
	'avis_aucun_resultat' => 'Nenhum resultado.',
	'avis_base_inaccessible' => 'Não foi possível conectar com a base de dados @base@.',
	'avis_chemin_invalide_1' => 'O caminho que você escolheu',
	'avis_chemin_invalide_2' => 'não parece válido. Por favor, volte à página anterior e verifique as informações fornecidas.',
	'avis_connexion_echec_1' => 'A conexão com a base de dados falhou.',
	'avis_connexion_echec_2' => 'Volte à página anterior e verifique as informações que você forneceu.',
	'avis_connexion_echec_3' => '<b>N.B.</b> Em diversos servidores, você precisa <b>solicitar</b> a ativação do seu acesso à base de dados antes de poder utilizá-la. Se você não consegue se conectar, verifique se você efetuou esse pedido.',
	'avis_connexion_erreur_creer_base' => 'Não foi possível criar a base de dados.',
	'avis_connexion_erreur_nom_base' => 'O nome da base só pode conter letras, números e traços',
	'avis_connexion_ldap_echec_1' => 'A conexão ao servidor LDAP falhou.',
	'avis_connexion_ldap_echec_2' => 'Volte à página anterior e verifique as informações que você forneceu.',
	'avis_connexion_ldap_echec_3' => 'Opcionalmente, não use o suporte LDAP para importar os usuários.',
	'avis_deplacement_rubrique' => 'Atenção! Esta seção contém @contient_breves@ nota@scb@: se você a transferir, por favor, marque este quadrado.',
	'avis_erreur_connexion_mysql' => 'Erro de conexão SQL',
	'avis_espace_interdit' => '<b>Área interdita</b> <div>O SPIP já está instalado.</div>',
	'avis_lecture_noms_bases_1' => 'O programa de instalação não pôde ler os nomes das bases de dados instaladas.',
	'avis_lecture_noms_bases_2' => 'Ou nenhuma base de dados esta disponível, ou a função que permite listar as bases foi desativada por razões de segurança (o que é o caso de diversos provedores de hospedagem).',
	'avis_lecture_noms_bases_3' => 'No segundo caso, é provável que uma base de dados com o nome do seu login possa ser utilizada:',
	'avis_non_acces_page' => 'Você não tem acesso a esta página.',
	'avis_operation_echec' => 'A operação falhou.',
	'avis_operation_impossible' => 'Operação impossível',
	'avis_suppression_base' => 'ATENÇÃO, a supressão dos dados é irreversível',

	// B
	'bouton_acces_ldap' => 'Incluir o acesso ao LDAP',
	'bouton_ajouter' => 'Incluir',
	'bouton_annuler' => 'Anular',
	'bouton_cache_activer' => 'Reativar o cache',
	'bouton_cache_desactiver' => 'Desativar temporariamente o cache',
	'bouton_demande_publication' => 'Solicitar a publicação desta matéria',
	'bouton_desactive_tout' => 'Desativar tudo',
	'bouton_desinstaller' => 'Desinstalar',
	'bouton_effacer_tout' => 'Apagar TUDO',
	'bouton_envoyer_message' => 'Mensagem definitiva: enviar',
	'bouton_fermer' => 'Fechar',
	'bouton_mettre_a_jour_base' => 'Atualizar a base de dados',
	'bouton_modifier' => 'Alterar',
	'bouton_radio_afficher' => 'Exibir',
	'bouton_radio_apparaitre_liste_redacteurs_connectes' => 'Exibir nas listas de redatores conectados',
	'bouton_radio_envoi_annonces_adresse' => 'Enviar os avisos para o endereço:',
	'bouton_radio_envoi_liste_nouveautes' => 'Enviar a lista de novidades',
	'bouton_radio_non_apparaitre_liste_redacteurs_connectes' => 'Não exibir na lista de redatores',
	'bouton_radio_non_envoi_annonces_editoriales' => 'Não enviar os avisos editoriais',
	'bouton_redirection' => 'REDIRECIONAMENTO',
	'bouton_reinitialiser_aux_valeurs_par_defaut' => 'Reiniciar aos valores padrão',
	'bouton_relancer_inscription' => 'Reiniciar o registro',
	'bouton_relancer_inscriptions' => 'Reiniciar os registros',
	'bouton_relancer_installation' => 'Reiniciar a instalação',
	'bouton_reset_password' => 'Criar uma nova senha e enviá-la por e-mail',
	'bouton_suivant' => 'Avançar',
	'bouton_tenter_recuperation' => 'Tentar uma reparação',
	'bouton_test_proxy' => 'Testar o proxy',
	'bouton_vider_cache' => 'Limpar o cache',

	// C
	'cache_modifiable_webmestre' => 'Este parâmetro é modificável pelo webmaster do site.',
	'calendrier_synchro' => 'Se você usa um programa de agenda compatível com <b>iCal</b>, você pode sincronizá-lo com as informações deste site.',
	'config_activer_champs' => 'Ativar os campos a seguir',
	'config_choix_base_sup' => 'indicar uma base neste servidor',
	'config_erreur_base_sup' => 'O SPIP não tem acesso à lista de bases acessíveis',
	'config_info_base_sup' => 'Se você tiver outras bases de dados para serem consultadas via SPIP, em seu servidor SQL ou em outro, o formulário abaixo permite configurá-las. Se você deixar determinados campos em branco, os dados de conexão da base principal serão utilizados.',
	'config_info_base_sup_disponibles' => 'Bases suplementares já consultáveis:',
	'config_info_enregistree' => 'A nova configuração foi gravada',
	'config_info_logos' => 'Cada elemento do site pode ter um ícone, bem como um ícone de «mouseOver»',
	'config_info_logos_utiliser' => 'Usar os ícones',
	'config_info_logos_utiliser_non' => 'Não usar o ícones',
	'config_info_logos_utiliser_survol' => 'Usar os ícones de mouseOver',
	'config_info_logos_utiliser_survol_non' => 'Não usar os ícones de mouseOver',
	'config_info_redirection' => 'Ao ativar esta opção, você poderá criar matérias virtuais, meras referências a matérias publicadas em outros sites ou fora do SPIP.',
	'config_redirection' => 'Matérias virtuais',
	'config_titre_base_sup' => 'Configuração de uma base suplementar',
	'config_titre_base_sup_choix' => 'Escolha uma base suplementar',
	'connexion_ldap' => 'Conexão:',
	'creer_et_associer_un_auteur' => 'Criar e vincular um autor',

	// D
	'date_mot_heures' => 'horas',

	// E
	'ecran_connexion_couleur_principale' => 'Cor principal',
	'ecran_connexion_image_fond' => 'Imagem de fundo',
	'ecran_connexion_image_fond_explication' => 'Usar uma imagem (formato JPEG, 1920x1080 pixels)',
	'ecran_connexion_image_revenir_couleur_defaut' => 'Reverter para a cor padrão',
	'ecran_connexion_titre' => 'Tela de conexão',
	'ecran_securite' => ' + tela de segurança @version@',
	'email' => 'e-mail',
	'email_2' => 'e-mail:',
	'en_savoir_plus' => 'Saiba mais',
	'entree_adresse_annuaire' => 'Endereço do catálogo',
	'entree_adresse_email' => 'Seu endereço de e-mail',
	'entree_adresse_email_2' => 'Endereço de e-mail',
	'entree_base_donnee_1' => 'Endereço da base de dados',
	'entree_base_donnee_2' => '(Frequentemente este endereço corresponde ao do seu site, às vezes ele corresponde ao nome «localhost», algumas vezes ele pode ser deixado completamente em branco.)',
	'entree_biographie' => 'Biografia curta em poucas palavras.',
	'entree_chemin_acces' => '<b>Informe</b> o caminho de acesso:',
	'entree_cle_pgp' => 'Sua chave PGP',
	'entree_cle_pgp_2' => 'Chave PGP',
	'entree_contenu_rubrique' => '(Conteúdo da seção em poucas palavras.)',
	'entree_identifiants_connexion' => 'Seus dados de conexão...',
	'entree_identifiants_connexion_2' => 'Dados de conexão',
	'entree_informations_connexion_ldap' => 'Informe neste formulário os dados de conexão ao seu catálogo LDAP.
Estas informações deverão ser fornecidas pelo administrador do sistema ou da rede.',
	'entree_infos_perso' => 'Quem é você?',
	'entree_infos_perso_2' => 'Quem é o autor?',
	'entree_interieur_rubrique' => 'No interior da seção:',
	'entree_liens_sites' => '<b>Link hipertexto</b> (referência, site a visitar...)',
	'entree_login' => 'Seu login',
	'entree_login_connexion_1' => 'O login de conexão',
	'entree_login_connexion_2' => '(Frequentemente corresponde ao seu login para acesso por FTP; às vezes pode ser deixado em branco)',
	'entree_mot_passe' => 'Sua senha',
	'entree_mot_passe_1' => 'A senha de conexão',
	'entree_mot_passe_2' => '(Frequentemente corresponde à sua senha para acesso por FTP; às vezes pode ser deixado em branco)',
	'entree_nom_fichier' => 'Por favor, informe o nome do arquivo @texte_compresse@:',
	'entree_nom_pseudo' => 'Seu nome ou apelido',
	'entree_nom_pseudo_1' => '(Seu nome ou apelido)',
	'entree_nom_pseudo_2' => 'Nome ou apelido',
	'entree_nom_site' => 'O nome do seu site',
	'entree_nom_site_2' => 'Nome do site do autor',
	'entree_nouveau_passe' => 'Nova senha',
	'entree_passe_ldap' => 'Senha',
	'entree_port_annuaire' => 'O número da porta do catálogo',
	'entree_signature' => 'Assinatura',
	'entree_titre_obligatoire' => '<b>Título</b> [Obrigatório]<br />',
	'entree_url' => 'O endereço (URL) do seu site',
	'entree_url_2' => 'Endereço (URL) do site',
	'erreur_connect_deja_existant' => 'Já existe um servidor com esse nome',
	'erreur_contenu_suspect' => 'Texto escapado',
	'erreur_email_deja_existant' => 'Esse endereço de email já está em uso.',
	'erreur_nom_connect_incorrect' => 'Este nome de servidor não é autorizado',
	'erreur_plugin_attribut_balise_manquant' => 'Atributo @attribut@ faltando no tag @balise@.',
	'erreur_plugin_desinstalation_echouee' => 'A desinstalação do plugin falhou. No entanto, você pode desativá-lo.',
	'erreur_plugin_fichier_absent' => 'Arquivo ausente',
	'erreur_plugin_fichier_def_absent' => 'Arquivo de definição ausente',
	'erreur_plugin_nom_fonction_interdit' => 'Nome de função não permitido',
	'erreur_plugin_nom_manquant' => 'Nome do plugin ausente',
	'erreur_plugin_prefix_manquant' => 'Área de nomeação do plugin não definida',
	'erreur_plugin_tag_plugin_absent' => '&lt;plugin&gt; ausente no arquivo de definição',
	'erreur_plugin_version_manquant' => 'Versão do plugin ausente',
	'erreur_type_fichier' => 'Tipo de arquivo incorreto',

	// H
	'htaccess_a_simuler' => 'Aviso: a configuração do seu servidor HTTP não leva em conta os arquivos @htaccess@. Para poder garantir um bom nível de segurança, é preciso que você altere esta configuração, ou que as constantes @constantes@ (definíveis no arquivo mes_options.php) tenham como valor os diretórios abaixo de @document_root@.',
	'htaccess_inoperant' => 'htaccess inoperante',

	// I
	'ical_info1' => 'Esta página apresenta diversos métodos para se manter a par da atividade deste site.',
	'ical_info2' => 'Para mais informações sobre todas estas técnicas, não deixe de consultar <a href="@spipnet@">a documentação do SPIP</a>.',
	'ical_info_calendrier' => 'Dois calendários estão à sua disposição. O primeiro é um mapa do site anunciando todas as matérias publicadas. O segundo contém os avisos editoriais bem como suas últimas mensagens privadas: ele lhe é reservado graças a uma chave pessoal, que você pode alterar a qualquer momento ao renovar a sua senha.',
	'ical_methode_http' => 'Transferência',
	'ical_methode_webcal' => 'Sincronização (webcal://)',
	'ical_texte_js' => 'Uma linha de javascript permite-lhe exibir de forma simples, em qualquer site que lhe pertença, as matérias recentemente publicadas neste site.',
	'ical_texte_prive' => 'Este calendário, de uso estritamente pessoal, o informa sobre a atividade editorial privada deste site (tarefas e encontros pessoais, matérias e notas propostas...).',
	'ical_texte_public' => 'Este calendário permite-lhe acompanhar a atividade pública deste site (matérias e notas publicadas).',
	'ical_texte_rss' => 'Você pode sindicar as novidades deste site em qualquer leitor de arquivos em formato XML/RSS (Rich Site Summary). É também o formato que permite ao SPIP ler as novidades publicadas em outros sites que utilizem um formato de troca de informações compatível (sites sindicados).',
	'ical_titre_js' => 'Javascript',
	'ical_titre_mailing' => 'Mailing-list',
	'ical_titre_rss' => 'Arquivos de sindicação',
	'icone_accueil' => 'Página Inicial',
	'icone_activer_cookie' => 'Ativar o coockie de correspondência',
	'icone_activite' => 'Atividade',
	'icone_admin_plugin' => 'Gerenciamento dos plugins',
	'icone_administration' => 'Manutenção',
	'icone_afficher_auteurs' => 'Exibir os autores',
	'icone_afficher_visiteurs' => 'Exibir os visitantes',
	'icone_arret_discussion' => 'Não participar mais desta discussão',
	'icone_calendrier' => 'Calendário',
	'icone_configuration' => 'Configuração',
	'icone_creer_auteur' => 'Criar um novo autor e vinculá-lo a esta matéria',
	'icone_creer_mot_cle' => 'Criar uma nova palavra-chave e vinculá-la a esta matéria',
	'icone_creer_rubrique_2' => 'Criar uma nova seção',
	'icone_developpement' => 'Desenvolvimento',
	'icone_edition' => 'Edição',
	'icone_ma_langue' => 'Meu idioma',
	'icone_mes_infos' => 'Minhas informações',
	'icone_mes_preferences' => 'Minhas preferências',
	'icone_modifier_article' => 'Editar esta matéria',
	'icone_modifier_rubrique' => 'Editar esta seção',
	'icone_publication' => 'Publicação',
	'icone_relancer_signataire' => 'Reconfirmar o assinante',
	'icone_retour' => 'Voltar',
	'icone_retour_article' => 'Voltar para a matéria',
	'icone_squelette' => 'Templates',
	'icone_suivi_publication' => 'Acompanhamento da publicação',
	'icone_supprimer_cookie' => 'Excluir o cookie de correspondência',
	'icone_supprimer_rubrique' => 'Excluir esta seção',
	'icone_supprimer_signature' => 'Excluir esta assinatura',
	'icone_valider_signature' => 'Validar esta assinatura',
	'image_administrer_rubrique' => 'Você pode administrar esta seção',
	'impossible_modifier_login_auteur' => 'Não foi possível alterar o login.',
	'impossible_modifier_pass_auteur' => 'Não foi possível alterar a senha.',
	'info_1_article' => '1 matéria',
	'info_1_auteur' => '1 autor',
	'info_1_message' => '1 mensagem',
	'info_1_mot_cle' => '1 palavra-chave',
	'info_1_rubrique' => '1 seção',
	'info_1_visiteur' => '1 visitante',
	'info_activer_cookie' => 'Você pode ativar um <b>cookie de correspondência</b>, que lhe permitirá passar facilmente do site público para o site privado.',
	'info_activer_menu_developpement' => 'Exibir o menu Desenvolvimento',
	'info_admin_etre_webmestre' => 'Me conceder direitos de webmaster',
	'info_admin_je_suis_webmestre' => 'Eu sou <b>webmaster</b>',
	'info_admin_statuer_webmestre' => 'Dar a este administrador os direitos de webmaster',
	'info_admin_webmestre' => 'Este administrador é <b>webmaster</b>',
	'info_administrateur' => 'Administrador',
	'info_administrateur_1' => 'Administrador',
	'info_administrateur_2' => 'do site (<i>use com cuidado</i>)',
	'info_administrateur_site_01' => 'Se você é administrador do site, por favor,',
	'info_administrateur_site_02' => 'clique neste link',
	'info_administrateurs' => 'Administradores',
	'info_administrer_rubrique' => 'Você pode administrar esta seção',
	'info_adresse' => 'no endereço:',
	'info_adresse_desinscription' => 'Endereço da desinscrição:',
	'info_adresse_url' => 'Endereço (URL) do site público',
	'info_afficher_par_nb' => 'Exibir por',
	'info_aide_en_ligne' => 'Ajuda online SPIP',
	'info_ajout_image' => 'Assim que você incluir imagens e documentos anexados a uma matéria, o SPIP pode criar para você, automaticamente, ícones (miniaturas) das imagens inseridas. Isto permite, por exemplo, criar automaticamente uma galeria ou um portfólio.',
	'info_ajouter_rubrique' => 'Incluir outra seção para administrar:',
	'info_annonce_nouveautes' => 'Aviso das novidades',
	'info_article' => 'matéria',
	'info_article_2' => 'matérias',
	'info_article_a_paraitre' => 'As matérias pós-datadas para exibição',
	'info_articles_02' => 'matérias',
	'info_articles_2' => 'Matérias',
	'info_articles_auteur' => 'As matérias deste autor',
	'info_articles_miens' => 'Minhas matérias',
	'info_articles_tous' => 'Todas as matérias',
	'info_articles_trouves' => 'Matérias encontradas',
	'info_attente_validation' => 'Suas matérias aguardando validação',
	'info_aucun_article' => 'Nenhuma matéria',
	'info_aucun_auteur' => 'Nenhum autor',
	'info_aucun_message' => 'Nenhuma mensagem',
	'info_aucun_rubrique' => 'Nenhuma seção',
	'info_aujourdhui' => 'Hoje:',
	'info_auteur_gere_rubriques' => 'Este autor gerencia as seções a seguir:',
	'info_auteur_gere_toutes_rubriques' => 'Este autor gerencia <b>todas as seções</b>',
	'info_auteur_gere_toutes_rubriques_2' => 'Eu gerencio <b>todas as seções</b>',
	'info_auteurs' => 'Os autores',
	'info_auteurs_par_tri' => 'Autores@partri@',
	'info_auteurs_trouves' => 'Autores encontrados',
	'info_authentification_externe' => 'Autenticação externa',
	'info_avertissement' => 'Aviso',
	'info_barre_outils' => 'com sua barra de ferramentas?',
	'info_base_installee' => 'A estrutura da sua base de dados foi instalada.',
	'info_bio' => 'Biografia',
	'info_cache_desactive' => 'O cache está temporariamente desativado.',
	'info_chapeau' => 'Introdução',
	'info_chapeau_2' => 'Introdução:',
	'info_chemin_acces_1' => 'Opções: <b>Caminho de acesso no diretório</b>',
	'info_chemin_acces_2' => 'A partir daqui, você deverá configurar o caminho de acesso às informações do diretório. Esta informação é indispensávelpara ler os perfis dos usuários no diretório.',
	'info_chemin_acces_annuaire' => 'Opções: <b>Caminho de acesso no diretório</b>',
	'info_choix_base' => 'Terceiro passo:',
	'info_classement_1' => '<sup><u>o</u></sup> em @liste@',
	'info_classement_2' => '<sup><u>a</u></sup> em @liste@',
	'info_code_acces' => 'Não se esqueça dos seus dados de conexão!',
	'info_config_suivi' => 'Se este endereço corresponde a uma mailing-list, você pode informar abaixo o endereço onde os participantes do site podem se inscrever. Este endereço pode ser um URL (por exemplo a página de inscrição na lista pela Web), ou um endereço de e-mail dotado de um assunto específico (par exemple: <tt>@adresse_suivi@?subject=subscribe</tt>):',
	'info_config_suivi_explication' => 'Voce pode assinar a  mailing-list deste site. Você irá receber por e-mail, os avisos de matérias e notas propostos para publicação.',
	'info_confirmer_passe' => 'Confirmar a nova senha:',
	'info_conflit_edition_avis_non_sauvegarde' => 'Atenção os campos a seguir foram alterados por terceiros. As suas modificações nestes campos não foram, por isso, gravadas.',
	'info_conflit_edition_differences' => 'Diferenças:',
	'info_conflit_edition_version_enregistree' => 'A versão gravada:',
	'info_conflit_edition_votre_version' => 'A sua versão:',
	'info_connexion_base' => 'Teste de conexão com a base',
	'info_connexion_base_donnee' => 'Conexão à sua base de dados',
	'info_connexion_ldap_ok' => '<b>A conexão LDAP foi efetuada.</b><p>Você pode passar para o próximo passo.</p>',
	'info_connexion_mysql' => 'Sua conexão SQL',
	'info_connexion_ok' => 'A conexão foi obtida.',
	'info_contact' => 'Contato',
	'info_contenu_articles' => 'Conteúdo das matérias',
	'info_contributions' => 'Contribuições',
	'info_creation_paragraphe' => 'Para criar parágrafos, basta deixar linhas em branco.',
	'info_creation_rubrique' => 'Antes de poder escrever matérias, você deve criar, pelo menos, uma seção.<br />',
	'info_creation_tables' => 'Criação das tabelas da base',
	'info_creer_base' => '<b>Criar</b> uma nova base de dados:',
	'info_dans_rubrique' => 'Na seção:',
	'info_date_publication_anterieure' => 'Data de redação anterior:',
	'info_date_referencement' => 'DATA DE REFERENCIAMENTO DESTE SITE:',
	'info_derniere_etape' => 'Terminou!',
	'info_descriptif' => 'Descrição:',
	'info_desinstaller_plugin' => 'exclui os dados e desativa o plugin',
	'info_discussion_cours' => 'Discussões em andamento',
	'info_ecrire_article' => 'Antes de poder escrever matérias, você precisa criar pelo menos uma seção.',
	'info_email_envoi' => 'Endereço de e-mail de envio (opcional)',
	'info_email_envoi_txt' => 'Informe aqui o endereço a ser utilizado para enviar os e-mails (por padrão, o endereço de destino será usado como endereço de envio):',
	'info_email_webmestre' => 'Endereço de e-mail do webmaster',
	'info_envoi_email_automatique' => 'Envio automático de e-mails',
	'info_envoyer_maintenant' => 'Enviar agora',
	'info_etape_suivante' => 'Avançar para a próxima etapa',
	'info_etape_suivante_1' => 'Você pode passar para a próxima etapa.',
	'info_etape_suivante_2' => 'Você pode passar para a próxima etapa.',
	'info_exceptions_proxy' => 'Exceções para o proxy',
	'info_exportation_base' => 'exportação da base para @archive@',
	'info_facilite_suivi_activite' => 'Para facilitar o acompanhamento da atividade editorial do site, o SPIP pode enviar por e-mail, por exemplo a uma mailing-list de redatores, avisos dos pedidos de publicação e das validações das matérias.', # MODIF
	'info_fichiers_authent' => 'Arquivos de autenticação «.htpasswd»',
	'info_forums_abo_invites' => 'O seu site comporta fóruns por assinatura; os visitantes são convidados a se registrar no site público.',
	'info_gauche_admin_tech' => '<b>Esta página é acessível apenas aos responsáveis pelo site.</b><p>Ela dá acesso às diferentes funções de manutenção técnica. Algumas dessas funções possuem um processo específico de autenticação que exige acesso FTP ao website.</p>',
	'info_gauche_admin_vider' => '<b>Esta página é acessível apenas aos responsáveis pelo site.</b><p> Ela dá acesso às diferentes funções de manutenção técnica. Algumas dessas funções possuem um processo específico de autenticação que exige acesso FTP ao website.</p>',
	'info_gauche_auteurs' => 'Aqui, você encontra todos os autores do site.
Os status dos autores é indicado pela côr dos ícones (administrador = verde; redator = amarelo).',
	'info_gauche_auteurs_exterieurs' => 'Os autores externos, sem acesso ao site, são indicados por um ícone azul;
os autores excluídos por um ícone cinza.',
	'info_gauche_messagerie' => 'O sistema interno de mensagens permite a troca de mensagens entre redatores, a criação de lembretes (para seu uso pessoal) ou exibir anúncios na página de entrada da área privada (se você for administrador).',
	'info_gauche_statistiques_referers' => 'Esta página apresenta a lista dos  <i>referers</i>, ou seja, dos sites que contêm links para o seu site, unicamente para ontem e hoje; esta lista é zerada a cada 24 horas.',
	'info_gauche_visiteurs_enregistres' => 'Você encontrará aqui os visitantes registrados na área pública do site (fóruns por assinatura).',
	'info_generation_miniatures_images' => 'Geração de miniaturas das imagens',
	'info_gerer_trad_objets' => '@objets@ : gerenciar os links de tradução',
	'info_hebergeur_desactiver_envoi_email' => 'Alguns serviços de hospedagem desativam o envio automático de e-mails a partir dos seus servidores. Neste caso, as funcionalidades a seguir não funcionarão.',
	'info_hier' => 'ontem:',
	'info_identification_publique' => 'Sua identificação pública...',
	'info_image_process' => 'Por favor, selecione o melhor método de criação dos ícones, clicando na imagem correspondente.',
	'info_image_process2' => 'Se nenhuma imagem está sendo exibida, o servidor que hospeda o seu site não foi configurado para utilizar essas ferramentas. Se você deseja usar essas funções, contate o responsável técnico e solicite as extensões «GD» ou «Imagick».',
	'info_images_auto' => 'Imagens calculadas automaticamente',
	'info_informations_personnelles' => 'Informações pessoais',
	'info_inscription' => 'Inscrição online',
	'info_inscription_automatique' => 'Inscrição automática de novos redatores',
	'info_jeu_caractere' => 'Conjunto de caracteres do site',
	'info_jours' => 'dias',
	'info_laisser_champs_vides' => 'deixar estes campos vazios)',
	'info_langues' => 'Idiomas do site',
	'info_ldap_ok' => 'A autenticação LDAP está instalada.',
	'info_lien_hypertexte' => 'Link hipertexto:',
	'info_liste_nouveautes_envoyee' => 'A lista de novidades foi enviada',
	'info_liste_redacteurs_connectes' => 'Lista de redatores conectados',
	'info_login_existant' => 'Este login já está cadastrado.',
	'info_login_trop_court' => 'Login muito curto.',
	'info_login_trop_court_car_pluriel' => 'O login deve conter pelo menos @nb@ caracteres.',
	'info_logos' => 'Os ícones',
	'info_maximum' => 'máximo:',
	'info_meme_rubrique' => 'Na mesma seção',
	'info_message_en_redaction' => 'Suas mensagens em fase de redação',
	'info_message_technique' => 'Mensagem técnica:',
	'info_messagerie_interne' => 'Mensageria interna',
	'info_mise_a_niveau_base' => 'atualização da sua base SQL',
	'info_mise_a_niveau_base_2' => '{{Atenção!}} Você instalou uma versão de arquivos SPIP {anterior} à que estava instalada no site: a sua base de dados corre o risco de se corromper e o seu site não funcionar mais.<br />{{Reinstale os arquivos SPIP.}}',
	'info_modification_enregistree' => 'Sua alteração foi gravada',
	'info_modifier_auteur' => 'Editar o autor:',
	'info_modifier_rubrique' => 'Editar a seção:',
	'info_modifier_titre' => 'Editar: @titre@',
	'info_mon_site_spip' => 'Meu site SPIP',
	'info_moyenne' => 'média:',
	'info_multi_cet_article' => 'Idioma desta matéria:',
	'info_multi_langues_choisies' => 'Por favor, selecione a seguir os idiomas à disposição dos redatores do seu site.
Os idiomas já utilizados no site (no topo da lista) não podem ser desativados.',
	'info_multi_objets' => '@objets@ : ativar o menu de idioma',
	'info_multi_secteurs' => '... apenas para as seções situadas na raiz?',
	'info_nb_articles' => '@nb@ matérias',
	'info_nb_auteurs' => '@nb@ autores',
	'info_nb_messages' => '@nb@ mensagens',
	'info_nb_mots_cles' => '@nb@ palavras-chave',
	'info_nb_rubriques' => '@nb@ seções',
	'info_nb_visiteurs' => '@nb@ visitantes',
	'info_nom' => 'Nome',
	'info_nom_destinataire' => 'Nome do destinatário',
	'info_nom_pas_conforme' => 'tags HTML não são permitidas',
	'info_nom_site' => 'Nome do seu site',
	'info_nombre_articles' => '@nb_articles@ matérias,',
	'info_nombre_rubriques' => '@nb_rubriques@ seções,',
	'info_nombre_sites' => '@nb_sites@ sites,',
	'info_non_deplacer' => 'Não mover...',
	'info_non_envoi_annonce_dernieres_nouveautes' => 'O SPIP pode enviar regularmente o anúncio das últimas novidades do site (matérias e notas publicadas recentemente).',
	'info_non_envoi_liste_nouveautes' => 'Não enviar a lista de novidades',
	'info_non_modifiable' => 'não pode ser modificado',
	'info_non_suppression_mot_cle' => 'Eu não quero excluir esta palavra-chave.',
	'info_notes' => 'Observações',
	'info_nouvel_article' => 'Nova matéria',
	'info_nouvelle_traduction' => 'Nova tradução:',
	'info_numero_article' => 'MATÉRIA NÚMERO:',
	'info_obligatoire_02' => '(obrigatório)',
	'info_option_accepter_visiteurs' => 'Aceitar a inscrição de visitantes do site público',
	'info_option_ne_pas_accepter_visiteurs' => 'Recusar a inscrição dos visitantes',
	'info_options_avancees' => 'OPÇÕES AVANÇADAS',
	'info_ou' => 'ou...',
	'info_page_interdite' => 'Página não autorizada',
	'info_par_nom' => 'por nome',
	'info_par_nombre_article' => 'por número de matérias',
	'info_par_statut' => 'por status',
	'info_par_tri' => '’(por @tri@)’',
	'info_passe_trop_court' => 'Senha muito curta.',
	'info_passe_trop_court_car_pluriel' => 'A senha deve conter pelo menos @nb@ caracteres.',
	'info_passes_identiques' => 'As duas senhas não são idênticas.',
	'info_plus_cinq_car' => 'mais de 5 caracteres',
	'info_plus_cinq_car_2' => '(Mais de 5 caracteres)',
	'info_plus_trois_car' => '(Mais de 3 caracteres)',
	'info_popularite' => 'popularidade: @popularite@; visitas: @visites@',
	'info_post_scriptum' => 'Rodapé',
	'info_post_scriptum_2' => 'Rodapé:',
	'info_pour' => 'para',
	'info_preview_texte' => 'É possível visualizar os diferentes elementos editoriais do site que tenham  pelo menos o status de «proposto», bem como os elementos em fase de redação de que se é autor. Esta funcionalidade deve estar disponível para os administradores, para os redatores, ou para ninguém?',
	'info_procedez_par_etape' => 'proceder passo-a-passo',
	'info_procedure_maj_version' => 'o procedimento de atualização deve ser rodado para adaptar a base de dados à nova versão do SPIP.',
	'info_proxy_ok' => 'Teste do proxy bem sucedido',
	'info_ps' => 'P.S.',
	'info_publier' => 'publicar',
	'info_publies' => 'Suas matérias publicadas online',
	'info_question_accepter_visiteurs' => 'Se os templates do seu site prevêem o cadastramento de visitantes sem acesso à área privada, por favor, ative a opção abaixo:',
	'info_question_inscription_nouveaux_redacteurs' => 'Você quer aceitar inscrições de novos redatores a partir do site público? Se você aceitar, os visitantes poderão se cadastrar através de um formulário automatizado, tendo acesso à área privada para propôr as suas próprias matérias. <div class="notice">Durante a fase de inscrição, os usuários recebem um e-mail automático, fornecendo-lhes os seus códigos de acesso à área privada. Alguns serviços de hospedagem desativam o envio de e-mails a partir dos seus servidores: nesse caso, a inscrição automática é impossível.</div>',
	'info_qui_edite' => '@nom_auteur_modif@ trabalhou neste conteúdo há @date_diff@ minutos',
	'info_racine_site' => 'Raiz do site',
	'info_recharger_page' => 'Por favor, atualize esta página em alguns instantes.',
	'info_recherche_auteur_zero' => 'Nenhum resultado para «@cherche_auteur@».',
	'info_recommencer' => 'Por favor, recomece.',
	'info_redacteur_1' => 'Redator',
	'info_redacteur_2' => 'com acesso à área privada (<i>recomendado</i>)',
	'info_redacteurs' => 'Redatores',
	'info_redaction_en_cours' => 'EM FASE DE REDAÇÃO',
	'info_redirection' => 'Redirecionamento',
	'info_redirection_activee' => 'O redirecionamento foi ativado.',
	'info_redirection_boucle' => 'Você tentou redirecionar a matéria para ela mesma.',
	'info_redirection_desactivee' => 'O redirecionamento foi excluído.',
	'info_refuses' => 'Suas matérias recusadas',
	'info_reglage_ldap' => 'Opções: <b>Configuração da importação LDAP</b>',
	'info_renvoi_article' => '<b>Redirecionamento.</b> Esta matéria redireciona para a página:',
	'info_reserve_admin' => 'Apenas os administradores podem alterar este endereço.',
	'info_restreindre_rubrique' => 'Restringir o gerenciamento à seção:',
	'info_resultat_recherche' => 'Resultados da busca:',
	'info_rubriques' => 'Seções',
	'info_rubriques_02' => 'seções',
	'info_rubriques_trouvees' => 'Seções encontradas',
	'info_sans_titre' => 'Sem título',
	'info_selection_chemin_acces' => '<b>Selecione</b> a seguir o caminho para acessar o diretório:',
	'info_signatures' => 'assinaturas',
	'info_site' => 'Site',
	'info_site_2' => 'site:',
	'info_site_min' => 'site',
	'info_site_reference_2' => 'Site referenciado',
	'info_site_web' => 'Website:',
	'info_sites' => 'sites',
	'info_sites_lies_mot' => 'Os sites referenciados vinculados a esta palavra-chave',
	'info_sites_proxy' => 'Utilizar um proxy',
	'info_sites_trouves' => 'Sites encontrados',
	'info_sous_titre' => 'Subtítulo:',
	'info_statut_administrateur' => 'Administrador',
	'info_statut_auteur' => 'Status deste autor:',
	'info_statut_auteur_2' => 'Eu sou',
	'info_statut_auteur_a_confirmer' => 'Inscrição a confirmar',
	'info_statut_auteur_autre' => 'Outro status:',
	'info_statut_redacteur' => 'Redator',
	'info_statut_utilisateurs_1' => 'Status padrão dos usuários importados',
	'info_statut_utilisateurs_2' => 'Escolha o status atribuído às pessoas que constam do diretório LDAP, quando elas se conectarem pela primeira vêz. Você poderá, em seguida, alterar caso a caso este valor para cada autor.',
	'info_suivi_activite' => 'Acompanhamento da atividade editorial',
	'info_surtitre' => 'Sobretítulo:',
	'info_syndication_integrale_1' => 'O seu site propõe arquivos de sindicação (ver «<a href="@url@">@titre@</a>»).',
	'info_syndication_integrale_2' => 'Você deseja transmitir as matérias integralmente, ou difundir apenas um resumo de algumas centenas de caracteres?',
	'info_table_prefix' => 'Você pode alterar o prefixo do nome das tabelas de dados (indispensável no caso de pretender instalar diversos sites na mesma base de dados). Este prefixo deve estar em minúsculas, não acentuadas, e sem espaços.',
	'info_taille_maximale_images' => 'SPIP irá testar o tamanho máximo das imagens que o sistema pode tratar (em milhões de pixels).<br />As imagens muito grandes não serão reduzidas.',
	'info_taille_maximale_vignette' => 'Tamanho máximo dos ícones gerados pelo sistema:',
	'info_terminer_installation' => 'Você pode agora terminar o procedimento de instalação padrão.',
	'info_texte' => 'Texto',
	'info_texte_explicatif' => 'Texto explicativo',
	'info_texte_long' => '(o texto é longo: ele aparecerá em diversas partes que serão recombinadas após validação.)',
	'info_texte_message' => 'Texto da sua mensagem',
	'info_texte_message_02' => 'Texto da mensagem',
	'info_titre' => 'Título:',
	'info_total' => 'total:',
	'info_tous_articles_en_redaction' => 'Todas as matérias em fase de redação',
	'info_tous_articles_presents' => 'Todas as matérias publicadas nesta seção',
	'info_tous_articles_refuses' => 'Todas as matérias recusadas',
	'info_tous_les' => 'todos os:',
	'info_tout_site' => 'Todo o site',
	'info_tout_site2' => 'A matéria não foi traduzida para este idioma.',
	'info_tout_site3' => 'A matéria foi traduzida para este idioma, mas foram feitas alterações na matéria de referência. A tradução procisa ser atualizada.',
	'info_tout_site4' => 'A matéria foi traduzida para este idioma e a tradução está em dia.',
	'info_tout_site5' => 'Matéria original.',
	'info_tout_site6' => '<b>Atenção:</b> apenas as matérias originais estão exibidas.
As traduções estão associadas ao original, numa côr que indica o seu status:',
	'info_traductions' => 'Traduções',
	'info_travail_colaboratif' => 'Trabalho colaborativo nas matérias',
	'info_un_article' => 'uma matéria,',
	'info_un_site' => 'um site,',
	'info_une_rubrique' => 'uma seção,',
	'info_une_rubrique_02' => '1 seção',
	'info_url' => 'URL:',
	'info_url_proxy' => 'URL do proxy',
	'info_url_proxy_pas_conforme' => 'O URL do proxy não é válido.',
	'info_url_site_pas_conforme' => 'O URL do site não é válido.',
	'info_url_test_proxy' => 'URL de teste',
	'info_urlref' => 'Link hipertexto:',
	'info_utilisation_spip' => 'Você pode agora começar a utilizar o sistema de publicação assistida...',
	'info_visites_par_mois' => 'Exibir por mês:',
	'info_visiteur_1' => 'Visitante',
	'info_visiteur_2' => 'do site público',
	'info_visiteurs' => 'Visitantes',
	'info_visiteurs_02' => 'Visitantes do site público',
	'info_webmestre_forces' => 'Os webmasters são definidos em <tt>@file_options@</tt>.',
	'install_adresse_base_hebergeur' => 'Endereço da base de dados atribuído pelo serviço de hospedagem:',
	'install_connect_ok' => 'A nova base de dados foi corretamente declarada sob o nome de servidor @connect@.',
	'install_echec_annonce' => 'A instalação irá, provavelmente, falhar, ou levar a um site que não funciona...',
	'install_extension_mbstring' => 'O SPIP não funciona com:',
	'install_extension_php_obligatoire' => 'O SPIP exige a extensão php:',
	'install_login_base_hebergeur' => 'Login de conexão atribuído pelo serviço de hospedagem:',
	'install_nom_base_hebergeur' => 'Nome da base atribuído pelo serviço de hospedagem:',
	'install_pas_table' => 'Base atualmente sem tabelas',
	'install_pass_base_hebergeur' => 'Senha de conexão atribuída pelo serviço de hospedagem',
	'install_php_version' => 'PHP versão @version@ é insuficiente (mínimo = @minimum@)',
	'install_select_langue' => 'Escolha um idioma e clique no botão «avançar» para iniciar o procedimento de instalação.',
	'install_select_type_db' => 'Indicar o tipo de base de dados:',
	'install_select_type_mysql' => 'MySQL',
	'install_select_type_pg' => 'PostgreSQL',
	'install_select_type_sqlite2' => 'SQLite 2',
	'install_select_type_sqlite3' => 'SQLite 3',
	'install_serveur_hebergeur' => 'Servidor de base de dados atribuído pelo serviço de hospedagem',
	'install_table_prefix_hebergeur' => 'Prefixo de tabela atribuído pelo serviço de hospedagem:',
	'install_tables_base' => 'Tabelas da base',
	'install_types_db_connus' => 'SPIP pode usar <b>MySQL</b> (a mais comum), e <b>SQLite</b>.',
	'install_types_db_connus_avertissement' => 'O suporte ao <b>PostgreSQL</b> é também proposto a título experimental',
	'instituer_erreur_statut_a_change' => 'O status já foi alterado',
	'instituer_erreur_statut_non_autorise' => 'Você não pode escolher este status',
	'intem_redacteur' => 'redator',
	'intitule_licence' => 'Licença',
	'item_accepter_inscriptions' => 'Aceitar as inscrições',
	'item_activer_messages_avertissement' => 'Ativar as mensagens de aviso',
	'item_administrateur_2' => 'administrador',
	'item_afficher_calendrier' => 'Exibir no calendário',
	'item_autoriser_syndication_integrale' => 'Difundir a íntegra das matérias nos arquivos de sindicação',
	'item_choix_administrateurs' => 'os administradores',
	'item_choix_generation_miniature' => 'Gerar automaticamente as miniaturas das imagens.',
	'item_choix_non_generation_miniature' => 'Não gerar as miniaturas das imagens.',
	'item_choix_redacteurs' => 'os redatores',
	'item_choix_visiteurs' => 'os visitantes do site público',
	'item_creer_fichiers_authent' => 'Criar os arquivos .htpasswd',
	'item_login' => 'Login',
	'item_messagerie_agenda' => 'Ativar as mesagens internas e a agenda',
	'item_mots_cles_association_articles' => 'às matérias',
	'item_mots_cles_association_rubriques' => 'às seções',
	'item_mots_cles_association_sites' => 'aos sites referenciados ou sindicados.',
	'item_non' => 'Não',
	'item_non_accepter_inscriptions' => 'Não aceitar inscrições',
	'item_non_activer_messages_avertissement' => 'Sem mensagens de aviso',
	'item_non_afficher_calendrier' => 'Não exibir no calendário',
	'item_non_autoriser_syndication_integrale' => 'Difundir apenas um resumo',
	'item_non_creer_fichiers_authent' => 'Não criar os arquivos',
	'item_non_messagerie_agenda' => 'Desativar as mensagens internas e a agenda',
	'item_non_publier_articles' => 'Não publicar as matérias antes da data de publicação fixada.',
	'item_nouvel_auteur' => 'Novo autor',
	'item_nouvelle_rubrique' => 'Nova seção',
	'item_oui' => 'Sim',
	'item_publier_articles' => 'Publicar as matérias seja qual for a sua data de publicação.',
	'item_reponse_article' => 'Resposta à matéria',
	'item_visiteur' => 'Visitante',

	// J
	'jour_non_connu_nc' => 'n.c.',

	// L
	'label_bando_outils' => 'Barra de ferramentas',
	'label_bando_outils_afficher' => 'Exibir as ferramentas',
	'label_bando_outils_masquer' => 'Esconder as ferramentas',
	'label_choix_langue' => 'Escolha o seu idioma',
	'label_nom_fichier_connect' => 'Informe o nome usado por este servidor',
	'label_slogan_site' => 'Slogan do site',
	'label_taille_ecran' => 'Largura da tela',
	'label_texte_et_icones_navigation' => 'Menu de navegação',
	'label_texte_et_icones_page' => 'Exibição na página',
	'ldap_correspondance' => 'herança do campo @champ@',
	'ldap_correspondance_1' => 'Herança dos campos LDAP',
	'ldap_correspondance_2' => 'Para cada um dos campos SPIP a seguir, indique o nome do campo LDAP correspondente. Deixe em branco para não preencher, separe por espaços ou vírgulas para tentar vários campos LDAP.',
	'lien_ajouter_auteur' => 'Incluir este autor',
	'lien_ajouter_une_rubrique' => 'Incluir esta seção',
	'lien_email' => 'e-mail',
	'lien_nom_site' => 'NOME DO SITE:',
	'lien_rapide_contenu' => 'Ir para o conteúdo',
	'lien_rapide_navigation' => 'Ir para a navegação',
	'lien_rapide_recherche' => 'Ir para a busca',
	'lien_retirer_auteur' => 'Retirar o autor',
	'lien_retirer_rubrique' => 'Excluir a seção',
	'lien_retirer_tous_auteurs' => 'Retirar todos os autores',
	'lien_retirer_toutes_rubriques' => 'Retirar todas as seções',
	'lien_site' => 'site',
	'lien_tout_decocher' => 'Desmarcar tudo',
	'lien_tout_deplier' => 'Expandir tudo',
	'lien_tout_replier' => 'Retrair tudo',
	'lien_tout_supprimer' => 'Excluir tudo',
	'lien_trier_nom' => 'Ordenar pelo nome',
	'lien_trier_nombre_articles' => 'Ordenar por número de matérias',
	'lien_trier_statut' => 'Ordenar pelo status',
	'lien_voir_en_ligne' => 'VER ONLINE:',
	'logo_article' => 'Ícone da matéria',
	'logo_auteur' => 'Ícone do autor',
	'logo_rubrique' => 'Ícone da seção',
	'logo_site' => 'Ícone deste site',
	'logo_standard_rubrique' => 'Ícone padrão das seções',
	'logo_survol' => 'Ícone para mouseOver',

	// M
	'menu_aide_installation_choix_base' => 'Seleção da sua base',
	'module_fichier_langue' => 'Arquivo de idioma',
	'module_raccourci' => 'Atalho',
	'module_texte_affiche' => 'Texto exibido',
	'module_texte_explicatif' => 'Você pode inserir os atalhos a seguir nos templates do seu site público. Eles serão traduzidos automaticamente para os idiomas para os quais exista um arquivo de idioma.',
	'module_texte_traduction' => 'O arquivo de idioma «@module@» está disponível em:',
	'mois_non_connu' => 'desconhecido',

	// N
	'nouvelle_version_spip' => 'A versão @version@ do SPIP está disponível',
	'nouvelle_version_spip_majeure' => 'Uma nova versão SPIP @version@ está disponível',

	// O
	'onglet_contenu' => 'Conteúdo',
	'onglet_declarer_une_autre_base' => 'Configurar outra base',
	'onglet_discuter' => 'Discutir',
	'onglet_interactivite' => 'Interatividade',
	'onglet_proprietes' => 'Propriedades',
	'onglet_repartition_actuelle' => 'atualmente',
	'onglet_sous_rubriques' => 'Subseções',

	// P
	'page_pas_proxy' => 'Esta página não deve passar pelo proxy',
	'pas_de_proxy_pour' => 'Se necessário, indique as máquinas ou domínios para os quais este proxy não se aplica (por exemplo: @exemple@)',
	'phpinfo' => 'Configuração PHP',
	'plugin_charge_paquet' => 'Carregamento do pacote @name@',
	'plugin_charger' => 'Transferir',
	'plugin_erreur_charger' => 'erro: não foi possível carregar @zip@',
	'plugin_erreur_droit1' => 'O diretório <code>@dest@</code> não está acessível para escrita.',
	'plugin_erreur_droit2' => 'Por favor, verifique os direitos deste diretório (e criá-lo, caso não exista), ou instalar os arquivos por FTP.',
	'plugin_erreur_zip' => 'falha pclzip: erro @status@',
	'plugin_etat_developpement' => 'em desenvolvimento',
	'plugin_etat_experimental' => 'experimental',
	'plugin_etat_stable' => 'estável',
	'plugin_etat_test' => 'em teste',
	'plugin_impossible_activer' => 'Não foi possível ativar o plugin @plugin@',
	'plugin_info_automatique1' => 'Se você deseja autorizar a instalaçào automática dos plugins, por favor:',
	'plugin_info_automatique1_lib' => 'Se você deseja autorizar a instalação automática desta biblioteca, por favor:',
	'plugin_info_automatique2' => 'crie um diretório <code>@rep@</code> ;',
	'plugin_info_automatique3' => 'verifique se o servidor está autorizado a escrever neste diretório',
	'plugin_info_automatique_creer' => 'a ser criado na raiz do site.',
	'plugin_info_automatique_exemples' => 'exemplos:',
	'plugin_info_automatique_ftp' => 'Você pode instalar os plugins, por FTP, no diretório <tt>@rep@</tt>',
	'plugin_info_automatique_lib' => 'Alguns plugins precisam também poder transferir arquivos para o diretório <code>lib/</code>, a ser criado, caso não exista, na raiz do site.',
	'plugin_info_automatique_liste' => 'Suas listas de plugins:',
	'plugin_info_automatique_liste_officielle' => 'os plugins oficiais',
	'plugin_info_automatique_liste_update' => 'Atualizar as listas',
	'plugin_info_automatique_ou' => 'ou...',
	'plugin_info_automatique_select' => 'Selecione abaixo um plugin: O SPIP o transferirá e o instalará no diretório <code>@rep@</code>; se o plugin já existir, será atualizado.',
	'plugin_info_credit' => 'Créditos',
	'plugin_info_erreur_xml' => 'A declaração deste plugin está incorreta',
	'plugin_info_install_ok' => 'Instalação bem sucedida',
	'plugin_info_necessite' => 'Requer:',
	'plugin_info_non_compatible_spip' => 'Este plugin não é compatível com esta versão do SPIP',
	'plugin_info_plugins_dist_1' => 'Os plugins abaixo são carregados e ativados no diretório @plugins_dist@.',
	'plugin_info_plugins_dist_2' => 'Eles não são desativáveis.',
	'plugin_info_telecharger' => 'transferir de @url@ e instalar em @rep@',
	'plugin_info_upgrade_ok' => 'Atualização bem sucedida',
	'plugin_librairies_installees' => 'Bibliotecas instaladas',
	'plugin_necessite_extension_php' => 'Requer a extensão PHP @plugin@ na versão @version@.',
	'plugin_necessite_extension_php_sans_version' => 'Requer a extensão PHP @plugin@',
	'plugin_necessite_lib' => 'Este plugin precisa da biblioteca @lib@',
	'plugin_necessite_php' => 'Requer @plugin@ na versão @version@.',
	'plugin_necessite_plugin' => 'Precisa do plugin @plugin@, na versão @version@.',
	'plugin_necessite_plugin_sans_version' => 'Precisa do plugin @plugin@',
	'plugin_necessite_spip' => 'É necessário o SPIP na versão @version@, pelo menos.',
	'plugin_source' => 'fonte: ',
	'plugin_titre_automatique' => 'Instalação automática',
	'plugin_titre_automatique_ajouter' => 'Incluir plugins',
	'plugin_titre_installation' => 'Instalação do plugin @plugin@',
	'plugin_titre_modifier' => 'Meus plugins',
	'plugin_utilise_extension_php' => 'A extensão PHP @plugin@ deve estar na versão @version@.',
	'plugin_utilise_php' => '@plugin@ deve estar na versão @version@.',
	'plugin_utilise_plugin' => 'O plugin @plugin@ deve estar na versão @version@.',
	'plugin_zip_active' => 'Continue para o ativar',
	'plugin_zip_adresse' => 'Indique abaixo o endereço de um arquivo zip de plugin a ser transferido, ou ainda o endereço de uma lista de plugins.',
	'plugin_zip_adresse_champ' => 'Endereço do plugin ou da lista',
	'plugin_zip_content' => 'Ele contém os arquivos a seguir (@taille@),<br />prontos para serem instalados no diretório <code>@rep@</code>',
	'plugin_zip_installe_finie' => 'O arquivo @zip@ foi descompactado e instalado.',
	'plugin_zip_installe_rep_finie' => 'O arquivo @zip@ foi descompactado e instalado no diretório @rep@',
	'plugin_zip_installer' => 'Você pode, agora, instalá-lo.',
	'plugin_zip_telecharge' => 'O arquivo @zip@ foi transferido',
	'plugins_actif_aucun' => 'Nenhum plugin ativado.',
	'plugins_actif_un' => 'Um plugin ativado.',
	'plugins_actifs' => '@count@ plugins ativados.',
	'plugins_actifs_liste' => 'Ativos',
	'plugins_compte' => '@count@ plugins',
	'plugins_disponible_un' => 'Um plugin disponível.',
	'plugins_disponibles' => '@count@ plugins disponiveis.',
	'plugins_erreur' => 'Erro nos plugins: @plugins@',
	'plugins_liste' => 'Lista dos plugins',
	'plugins_liste_dist' => 'Plugins bloqueados',
	'plugins_recents' => 'Plugins recentes.',
	'plugins_tous_liste' => 'Todos',
	'plugins_vue_hierarchie' => 'Hierarquia',
	'plugins_vue_liste' => 'Lista',
	'protocole_ldap' => 'Versão do protocolo:',

	// Q
	'queue_executer_maintenant' => 'Executar agora',
	'queue_info_purger' => 'Você pode excluir todas as tarefas de fundo em espera e reinicializar a lista com as tarefas periódicas',
	'queue_nb_jobs_in_queue' => '@nb@ tarefas em espera',
	'queue_next_job_in_nb_sec' => 'Próxima tarefa em @nb@ s',
	'queue_no_job_in_queue' => 'Nenhum tarefa em espera',
	'queue_one_job_in_queue' => '1 tarefa em espera',
	'queue_priorite_tache' => 'prioridade',
	'queue_purger_queue' => 'Reiniciar a lista de tarefas',
	'queue_titre' => 'Tarefas de fundo',

	// R
	'repertoire_plugins' => 'Diretório:',
	'required' => '(obrigatório)',

	// S
	'sans_heure' => 'sem hora',
	'statut_admin_restreint' => '(admin limitado)',
	'statut_webmestre' => 'webmaster',

	// T
	'tache_cron_asap' => 'Tarefa CRON @function@ (ASAP)',
	'tache_cron_secondes' => 'Tarefa CRON @function@ (a cada @nb@ s)',
	'taille_cache_image' => 'As imagens calculadas automaticamente pelo SPIP (ícones de documentos, títulos apresentados sob a forma gráfica, funções matemáticas em formato TeX...) ocupam, no diretório @dir@, um total de @taille@.',
	'taille_cache_infinie' => 'Este site não prevê limitação de tamanho do diretório do cache.',
	'taille_cache_maxi' => 'O SPIP tenta limitar o tamanho do diretório do cache deste site em cerca de <b>@octets@</b>.',
	'taille_cache_moins_de' => 'O tamanho do cache é menor do que @octets@.',
	'taille_cache_octets' => 'O tamanho atual do cache é de cerca de @octets@.',
	'taille_cache_vide' => 'O cache está vazio.',
	'taille_repertoire_cache' => 'Tamanho do diretório cache',
	'text_article_propose_publication' => 'Matéria proposta para publicação.',
	'texte_acces_ldap_anonyme_1' => 'Alguns servidores LDAP não aceitam nenhum acesso anônimo. Neste caso, é necessário especificar um identificador de acesso inicial de modo a poder, em seguida, pesquisar as informações no diretório. Na maior parte dos casos, entretanto, os campos a seguir poderão ser deixados em branco.',
	'texte_admin_effacer_01' => 'Este comando apaga <i>todo</i> o conteúdo da base de dados,incluindo <i>todos</i> os acessos dos redatores e administradores. Após executá-lo, você deverá reinstalar o SPIP para recriar uma nova base de dados bem como um acesso inicial de administrador.',
	'texte_adresse_annuaire_1' => '(Se o seu diretório está instalado na mesma máquina que este website, trata-se provavelmente de «localhost».)',
	'texte_ajout_auteur' => 'O autor a seguir foi incluído na matéria:',
	'texte_annuaire_ldap_1' => 'Se você tem acesso a um diretório LDAP, você poderá utilizá-lo para importar automaticamente os usuários para o SPIP.',
	'texte_article_statut' => 'Esta matéria está:',
	'texte_article_virtuel' => 'Matéria virtual',
	'texte_article_virtuel_reference' => '<b>Matéria virtual:</b> matéria referenciada no seu site SPIP, mas redirecionada para um outro URL. Para cancelar o redirecionamento, apague o URL abaixo.',
	'texte_aucun_resultat_auteur' => 'Nenhum resultado para "@cherche_auteur@"',
	'texte_auteur_messagerie' => 'Este site pode monitorar permanentemente a lista de editores conectados, permitindo-lhe trocar mensagens em tempo real. Você pode decidir não aparecer nessa lista (ficando "invisível" para os outros usuários).',
	'texte_auteurs' => 'OS AUTORES',
	'texte_choix_base_1' => 'Escolha a sua base:',
	'texte_choix_base_2' => 'O servidor SQL contém várias bases de dados.',
	'texte_choix_base_3' => '<b>Escolha</b> abaixo a que lhe foi atribuída pelo seu serviço de hospedagem:',
	'texte_choix_table_prefix' => 'Prefixo das tabelas:',
	'texte_compte_element' => '@count@ elemento',
	'texte_compte_elements' => '@count@ elementos',
	'texte_conflit_edition_correction' => 'Por favor, controle abaixo as diferenças entre as duas versões do texto; você pode também copiar as suas modificações e depois recomeçar.',
	'texte_connexion_mysql' => 'Consulte as informações fornecidas pelo seu serviço de hospedagem: nelas, você deverá encontrar o servidor de base de dados fornecido e os seus dados de conexão ao servidor SQL.',
	'texte_contenu_article' => '(Conteúdo da matéria em poucas palavras.)',
	'texte_contenu_articles' => 'De acordo com o layout adotado pelo seu site, você poderá decidir se certos elementos das matérias serão utilizados. Use a listagem abaixo para indicar quais elementos estão disponíveis.',
	'texte_crash_base' => 'Se a sua base de dados se corrompeu, você poderá tentar uma reparação automática.',
	'texte_creer_rubrique' => 'Antes de poder escrever matérias, você precisa criar uma seção.',
	'texte_date_creation_article' => 'DATA DE CRIAÇÃO DA MATÉRIA:',
	'texte_date_creation_objet' => 'Data de criação:', # on ajoute le &quot;:&quot;
	'texte_date_publication_anterieure' => 'Data de redação anterior:',
	'texte_date_publication_anterieure_nonaffichee' => 'Não exibir a data de redação anterior.',
	'texte_date_publication_article' => 'DATA DE PUBLICAÇÃO ONLINE:',
	'texte_date_publication_objet' => 'Data de publicação online:',
	'texte_definir_comme_traduction_rubrique' => 'Esta seção é uma tradução da seção número:',
	'texte_descriptif_rapide' => 'Descrição rápida',
	'texte_effacer_base' => 'Apagar a base de dados do SPIP',
	'texte_effacer_statistiques' => 'Apagar as estatísticas',
	'texte_en_cours_validation' => 'Os conteúdos abaixo estão propostos para publicação.',
	'texte_enrichir_mise_a_jour' => 'Você pode enriquecer a diagramação do seu texto usando «atalhos tipográficos».',
	'texte_fichier_authent' => '<b>O SPIP pode criar os arquivos especiais  <tt>.htpasswd</tt> e <tt>.htpasswd-admin</tt> no diretório @dossier@?</b><p>
Estes arquivos podem servir para restringir o acesso aos autores e administradores em outras áreas do seu site (programas externos de estatísticas, por exemplo).</p><p>
Se eles não forem úteis, você poderá deixar esta opção com o seu valor padrão (sem criar os arquivos).</p>',
	'texte_informations_personnelles_1' => 'O sistema vai criar agora um acesso personalizado ao site.',
	'texte_informations_personnelles_2' => '(Nota: trata-se de uma reinstalação, se o seu acesso funciona corretamente, você pode',
	'texte_introductif_article' => '(Texto introdutório da matéria.)',
	'texte_jeu_caractere' => 'É aconselhável usar no seu site o alfabeto universal (<tt>utf-8</tt>): ele permite a exibição de textos em todos os idiomas, e não tem problemas de compatibilidade com os navegadores modernos.',
	'texte_jeu_caractere_3' => 'O seu site está configurado atualmente com o conjunto de caracteres:',
	'texte_jeu_caractere_4' => 'Se isso não corresponde à realidade dos seus dados (por ex., em seguimento a um restauro da base de dados), ou se <em>você lançou este site</em> e deseja utilizar um outro conjunto de caracteres, por favor, indique-o aqui:',
	'texte_login_ldap_1' => '(Deixe em branco para acesso anônimo, ou informe o caminho completo, por exemplo «<tt>uid=dupont, ou=users, dc=mon-domaine, dc=com</tt>».)',
	'texte_login_precaution' => 'Atenção! Este é o login com o qual você está conectado agora. Use este formulário com cautela...',
	'texte_messagerie_agenda' => 'As mensagens internas permitem que os redatores se comuniquem entre si, diretamente da área privada do site. Elas estão associadas a uma agenda.',
	'texte_mise_a_niveau_base_1' => 'Você acabou de atualizar os arquivos do SPIP.
Agora é necessário atualizar a base de dados do site.',
	'texte_modifier_article' => 'Editar a matéria:',
	'texte_multilinguisme' => 'Se você deseja gerar objetos em diversos idiomas, com uma navegação complexa, você pode incluir um menu de seleção de idioma nesses objetos, de acordo com a estrutura do seu site.',
	'texte_multilinguisme_trad' => 'Você pode, igualmente, ativar um sistema de gerenciamento de links entre as diferentes traduções em certos objetos.',
	'texte_non_compresse' => '<i>não compactado</i> (seu servidor não suporta esta funcionalidade)',
	'texte_nouvelle_version_spip_1' => 'Você instalou uma nova versão do SPIP.',
	'texte_nouvelle_version_spip_2' => 'Esta nova versão precisa de uma atualização mais completa do que o normal. Se você é o webmaster do site, por favor, apague o arquivo @connect@ e retome a instalação de forma a incluir os seus parâmetros de conexão à base de dados.<p> (NB.: se você não se lembra dos seus parâmetros de conexão, consulte o arquivo @connect@ antes de apagá-lo...)</p>',
	'texte_operation_echec' => 'Volte à página anterior, escolha uma outra base de dados ou crie uma nova. Verifique as informações fornecidas pelo seu serviço de hospedagem.',
	'texte_plus_trois_car' => 'mais de 3 caracteres',
	'texte_plusieurs_articles' => 'Demasiados autores encontrados para "@cherche_auteur@":',
	'texte_port_annuaire' => '(O valor padrão indicado é geralmente conveniente.)',
	'texte_presente_plugin' => 'Esta página lista os plugins disponíveis para o site. Você pode ativar os plugins necessários marcando a opção correspondente.',
	'texte_proposer_publication' => 'Assim que a sua matéria estiver pronta, você pode propor a sua publicação.',
	'texte_proxy' => 'Em alguns casos (intranet, redes protegidas...), os sites remotos (documentação do SPIP, sites sindicados etc.) só estarão acessíveis através de um <i>proxy HTTP</i>. Nesse caso, informe abaixo o endereço, no formato @proxy_en_cours@.Geralmente, você pode deixar este campo vazio.',
	'texte_publication_articles_post_dates' => 'Que comportamento o SPIP deve adotar face às matérias em que a data de publicação está pré-datada?',
	'texte_rappel_selection_champs' => '[Não se esqueça de selecionar corretamente este campo.]',
	'texte_recalcul_page' => 'Se você quiser recalcular uma única página, passe para a área pública e clique no botão «atualizar».',
	'texte_recuperer_base' => 'Reparar a base de dados',
	'texte_reference_mais_redirige' => 'matéria referenciada no seu site em  SPIP, mas redirecionada para outro URL.',
	'texte_requetes_echouent' => '<b>Já que certas solicitações SQL falharam sistematicamente e sem razão aparente, é possível que a causa esteja na base de dados em si.</b><p>
O seu servidor SQL dispõe de uma funcionalidade de reparação das suas tabelas quando elas são danificadas por acidente. Você poderá tentar esta reparação; em caso de falha, conserve uma cópia da mensagem de erro, que poderá conter indícios do que não está funcionando...</p><p>
Se o problema persistir, contate o seu serviço de hospedagem.</p>',
	'texte_selection_langue_principale' => 'Você pode escolher abaixo o «idioma principal» do site. esta escolha não o obriga - felizmente! - a escrever as suas matérias no idioma selecionado, mas permite determinar:
 <ul><li>o formato padrão das datas no site público;</li>
 <li>a natureza do motor tipográfico que o SPIP deverá usar para a composição dos textos;</li>
 <li>o idioma usado nos formulários do site público;</li>
 <li>o idioma padrão exibido na área privada.</li></ul>',
	'texte_sous_titre' => 'Subtítulo',
	'texte_statistiques_visites' => '(barras escuras:  domingo / curva escura: evolução da média)',
	'texte_statut_attente_validation' => 'aguardando validação',
	'texte_statut_publies' => 'publicadas online',
	'texte_statut_refuses' => 'recusadas',
	'texte_suppression_fichiers' => 'Use este comando para excluir todos os arquivos que constam do cache do SPIP. Isto permite, por exemplo, forçar a reconstrução de todas as páginas, caso você tenha feito alterações importantes no layout ou na estrutura do site.',
	'texte_sur_titre' => 'Sobretítulo',
	'texte_table_ok' => ': esta tabela está OK.',
	'texte_tentative_recuperation' => 'Tentativa de reparação',
	'texte_tenter_reparation' => 'Tentar uma reparação da base de dados',
	'texte_test_proxy' => 'Para testar este proxy, informe aqui o endereço de um website que você deseje testar.',
	'texte_titre_02' => 'Título:',
	'texte_titre_obligatoire' => '<b>Título</b> [obrigatório]',
	'texte_travail_article' => '@nom_auteur_modif@ trabalhou nesta matéria há @date_diff@ minutos',
	'texte_travail_collaboratif' => 'Se é frequente acontecer de mais de um redator trabalhar em uma mesma matéria, o sistema pode exibir as matérias recentemente "abertas", de modo a evitar modificações concorrentes. Esta opção está desativada por padrão, para evitar a exibição de mensagens de aviso desnecessárias.',
	'texte_vide' => 'vazia',
	'texte_vider_cache' => 'Esvaziar o cache',
	'titre_admin_tech' => 'Manutenção técnica',
	'titre_admin_vider' => 'Manutenção técnica',
	'titre_ajouter_un_auteur' => 'Incluir um autor',
	'titre_ajouter_un_mot' => 'Incluir uma palavra-chave',
	'titre_cadre_afficher_article' => 'Exibir as matérias',
	'titre_cadre_afficher_traductions' => 'Exibir o status das traduções para os idiomas a seguir:',
	'titre_cadre_ajouter_auteur' => 'INCLUIR UM AUTOR:',
	'titre_cadre_interieur_rubrique' => 'Na seção',
	'titre_cadre_numero_auteur' => 'AUTOR NÚMERO',
	'titre_cadre_numero_objet' => '@objet@ NÚMERO:',
	'titre_cadre_signature_obligatoire' => '<b>Assinatura</b> [obrigatório]<br />',
	'titre_config_contenu_notifications' => 'Notificações',
	'titre_config_contenu_prive' => 'Na área privada',
	'titre_config_contenu_public' => 'No site público',
	'titre_config_fonctions' => 'Configuração do site',
	'titre_config_langage' => 'Configurar o idioma',
	'titre_configuration' => 'Configuração do site',
	'titre_configurer_preferences' => 'Configurar as suas preferências',
	'titre_configurer_preferences_menus' => 'Configurar as suas preferências de menus',
	'titre_conflit_edition' => 'Conflito durante a edição',
	'titre_connexion_ldap' => 'Opções: <b>Sua conexão LDAP</b>',
	'titre_groupe_mots' => 'GRUPO DE PALAVRAS-CHAVE:',
	'titre_identite_site' => 'Identidade do site',
	'titre_langue_article' => 'Idioma da matéria',
	'titre_langue_rubrique' => 'Idioma da seção',
	'titre_langue_trad_article' => 'IDIOMA E TRADUÇÕES DA MATÉRIA',
	'titre_les_articles' => 'AS MATÉRIAS',
	'titre_messagerie_agenda' => 'Mensagens internas e agenda',
	'titre_naviguer_dans_le_site' => 'Navegar no site...',
	'titre_nouvelle_rubrique' => 'Nova seção',
	'titre_numero_rubrique' => 'SEÇÃO NÚMERO:',
	'titre_page_articles_edit' => 'Editar: @titre@',
	'titre_page_articles_page' => 'As matérias',
	'titre_page_articles_tous' => 'Todo o site',
	'titre_page_calendrier' => 'Calendário @nom_mois@ @annee@',
	'titre_page_config_contenu' => 'Configuração do site',
	'titre_page_delete_all' => 'supressão total e irreversível',
	'titre_page_recherche' => 'Resultados da busca por @recherche@',
	'titre_page_statistiques_referers' => 'Estatísticas (links de entrada)',
	'titre_page_upgrade' => 'Atualização do SPIP',
	'titre_preference_menus_favoris' => 'Menus favoritos',
	'titre_publication_articles_post_dates' => 'Publicação de matérias pós-datadas',
	'titre_reparation' => 'Reparação',
	'titre_suivi_petition' => 'Acompanhamento das petições',
	'tls_ldap' => 'Transport Layer Security:',
	'trad_article_traduction' => 'Todas as versões desta matéria:',
	'trad_delier' => 'Desvincular destas traduções',
	'trad_lier' => 'Esta matéria é uma tradução da matéria número:',
	'trad_new' => 'Escrever uma nova tradução',

	// U
	'utf8_convert_erreur_orig' => 'Erro: o conjunto de caracteres @charset@ não é suportado.',

	// V
	'version' => 'Versão:'
);
